"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getStepDefinitionPatterns = exports.getStepDefinitionPaths = void 0;
const path_1 = __importDefault(require("path"));
const glob_1 = __importDefault(require("glob"));
const util_1 = __importDefault(require("util"));
const is_path_inside_1 = __importDefault(require("is-path-inside"));
const debug_1 = __importDefault(require("./debug"));
async function getStepDefinitionPaths(configuration, filepath) {
    const files = (await Promise.all(getStepDefinitionPatterns(configuration, filepath).map((pattern) => util_1.default.promisify(glob_1.default)(pattern, { nodir: true })))).reduce((acum, el) => acum.concat(el), []);
    if (files.length === 0) {
        debug_1.default("found no step definitions");
    }
    else {
        debug_1.default(`found step definitions ${util_1.default.inspect(files)}`);
    }
    return files;
}
exports.getStepDefinitionPaths = getStepDefinitionPaths;
function trimFeatureExtension(filepath) {
    return filepath.replace(/\.feature$/, "");
}
function getStepDefinitionPatterns(configuration, filepath) {
    const fullIntegrationFolder = path_1.default.isAbsolute(configuration.cypress.integrationFolder)
        ? configuration.cypress.integrationFolder
        : path_1.default.join(configuration.cypress.projectRoot, configuration.cypress.integrationFolder);
    if (!is_path_inside_1.default(filepath, fullIntegrationFolder)) {
        throw new Error(`${filepath} is not inside ${fullIntegrationFolder}`);
    }
    if (!is_path_inside_1.default(filepath, configuration.cypress.projectRoot)) {
        throw new Error(`${filepath} is not inside ${configuration.cypress.projectRoot}`);
    }
    debug_1.default(`looking for step definitions using ${util_1.default.inspect(configuration.preprocessor.stepDefinitions)}`);
    const filepathReplacement = trimFeatureExtension(path_1.default.relative(fullIntegrationFolder, filepath));
    debug_1.default(`replacing [filepath] with ${util_1.default.inspect(filepathReplacement)}`);
    return (typeof configuration.preprocessor.stepDefinitions === "string"
        ? [configuration.preprocessor.stepDefinitions]
        : configuration.preprocessor.stepDefinitions).map((pattern) => path_1.default.join(configuration.cypress.projectRoot, pattern.replace("[filepath]", filepathReplacement)));
}
exports.getStepDefinitionPatterns = getStepDefinitionPatterns;
